@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Draw fretboard chord diagrams
 
-our $VERSION = '0.1000';
+our $VERSION = '0.1001';
 
 use Moo;
 use strictures 2;
@@ -114,13 +114,10 @@ sub BUILD {
 
     my %notes;
 
-    my $n = 0;
-
+    my $string = 0;
     for my $i ( @index ) {
-        $n++;
-
-        # Make a scale note list for each string
-        $notes{$n} = [ map { $scale[ ($i + $_) % @scale ] } 0 .. @scale - 1 ];
+        # Make a scale note list for the string
+        $notes{++$string} = [ map { $scale[ ($i + $_) % @scale ] } 0 .. @scale - 1 ];
     }
 
     $self->{fretboard} = \%notes;
@@ -196,27 +193,7 @@ sub draw {
             );
         }
 
-        if (
-            ( $self->position + $fret == 3 )
-            ||
-            ( $self->position + $fret == 5 )
-            ||
-            ( $self->position + $fret == 7 )
-            ||
-            ( $self->position + $fret == 9 )
-            ||
-            ( $self->position + $fret == 12 )
-            ||
-            ( $self->position + $fret == 15 )
-            ||
-            ( $self->position + $fret == 17 )
-            ||
-            ( $self->position + $fret == 19 )
-            ||
-            ( $self->position + $fret == 21 )
-            ||
-            ( $self->position + $fret == 24 )
-        ) {
+        if ( $self->_fret_match($fret) ) {
             $i->circle(
                 color => $GRAY,
                 r     => $SPACE / 8,
@@ -359,27 +336,7 @@ sub _draw_horiz {
             );
         }
 
-        if (
-            ( $self->position + $fret == 3 )
-            ||
-            ( $self->position + $fret == 5 )
-            ||
-            ( $self->position + $fret == 7 )
-            ||
-            ( $self->position + $fret == 9 )
-            ||
-            ( $self->position + $fret == 12 )
-            ||
-            ( $self->position + $fret == 15 )
-            ||
-            ( $self->position + $fret == 17 )
-            ||
-            ( $self->position + $fret == 19 )
-            ||
-            ( $self->position + $fret == 21 )
-            ||
-            ( $self->position + $fret == 24 )
-        ) {
+        if ( $self->_fret_match($fret) ) {
             $i->circle(
                 color => $GRAY,
                 r     => $SPACE / 8,
@@ -458,6 +415,30 @@ sub _draw_horiz {
     $self->_output_image($i);
 }
 
+sub _fret_match {
+    my ($self, $fret) = @_;
+    return
+        ( $self->position + $fret == 3 )
+        ||
+        ( $self->position + $fret == 5 )
+        ||
+        ( $self->position + $fret == 7 )
+        ||
+        ( $self->position + $fret == 9 )
+        ||
+        ( $self->position + $fret == 12 )
+        ||
+        ( $self->position + $fret == 15 )
+        ||
+        ( $self->position + $fret == 17 )
+        ||
+        ( $self->position + $fret == 19 )
+        ||
+        ( $self->position + $fret == 21 )
+        ||
+        ( $self->position + $fret == 24 );
+}
+
 sub _output_image {
     my ($self, $img) = @_;
     my $name = $self->outfile . '.' . $self->type;
@@ -484,7 +465,7 @@ Music::FretboardDiagram - Draw fretboard chord diagrams
 
 =head1 VERSION
 
-version 0.1000
+version 0.1001
 
 =head1 SYNOPSIS
 
